/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.jdbcconnections.service;

/**
 * Configuration of the JNDI JDBC Interceptor.
 *
 * @author Florent Benoit
 */
public class JNDIInterceptorsConfiguration {

    /**
     * Interceptor is present/enabled or not ?
     */
    private boolean jndiInterceptorEnabled = false;

    /**
     * Regexp of the interceptor.
     */
    private String regExp = "";

    /**
     * Allows to force the close of the connection
     */
    private boolean forceClose = false;

    /**
     * @return true if the interceptor is present.
     */
    public boolean isJndiInterceptorEnabled() {
        return jndiInterceptorEnabled;
    }

    /**
     * The interceptor is enabled/disabled ?
     *
     * @param jndiInterceptorEnabled the boolean value
     */
    public void setJndiInterceptorEnabled(final boolean jndiInterceptorEnabled) {
        this.jndiInterceptorEnabled = jndiInterceptorEnabled;
    }

    /**
     * @return the regular expression.
     */
    public String getRegExp() {
        return regExp;
    }

    /**
     * Sets the regexp used to find the matching datasources.
     *
     * @param regExp the regexp value
     */
    public void setRegExp(final String regExp) {
        this.regExp = regExp;
    }

    /**
     * @return true if the busy connections are automatically closed() at the
     *         end of the call.
     */
    public boolean isForceClose() {
        return forceClose;
    }

    /**
     * Change the value of the close parameter
     *
     * @param forceClose the boolean value
     */
    public void setForceClose(final boolean forceClose) {
        this.forceClose = forceClose;
    }

}
